==> bluegenes-0.9.12.jar: META-INF/leiningen/org.intermine/bluegenes/README.md <==


# BlueGenes

Travis: [![Build Status](https://travis-ci.org/intermine/bluegenes.svg?branch=dev)](https://travis-ci.org/intermine/bluegenes)

_An InterMine Web-based GUI_


## About

BlueGenes is designed to make searching and analysing genomic data easy. It's powered by [InterMine](http://intermine.org/) web services, meaning that the data from over 30 InterMines worldwide can be accessed from the same familiar interface.

### Screenshots

![BlueGenes screenshots](http://i.imgur.com/zwp0uxM.jpg)


## Try Online

[BlueGenes Live](http://bluegenes.apps.intermine.org/)


## Contributing

Check out our [contributing guidelines](https://github.com/intermine/bluegenes/blob/dev/CONTRIBUTING.md).


### Setting up a local development environment

[Configuring a local build](docs/configuring.md)

[Building instructions (for both Dev and Production builds)](docs/building.md).


## Need further help?

- Regarding InterMine- and InterMine webservices-related problems, check out the [InterMine documentation](http://intermine.readthedocs.io/en/latest/about/contact-us/)
- Email our [dev list](http://intermine.readthedocs.io/en/latest/support/mailing-list/)
- [Chat with us](http://chat.intermine.org) during UK office hours


## License

Copyright (C) since 2016, BlueGenes contributors

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, version 2.1.

You should have received a copy of the GNU Lesser General Public License along with this program.
If not, see <http://www.gnu.org/licenses/>.

==> bluegenes-0.10.0.jar: META-INF/leiningen/org.intermine/bluegenes/README.md <==


# BlueGenes

Travis: [![Build Status](https://travis-ci.org/intermine/bluegenes.svg?branch=dev)](https://travis-ci.org/intermine/bluegenes)

CircleCI: [![CircleCI](https://circleci.com/gh/intermine/bluegenes.svg?style=svg)](https://circleci.com/gh/intermine/bluegenes)

_An InterMine Web-based GUI_


## About

BlueGenes is designed to make searching and analysing genomic data easy. It's powered by [InterMine](http://intermine.org/) web services, meaning that the data from over 30 InterMines worldwide can be accessed from the same familiar interface.

### Screenshots

![BlueGenes screenshots](http://i.imgur.com/zwp0uxM.jpg)


## Try Online

[BlueGenes Live](http://bluegenes.apps.intermine.org/)


## Contributing

Check out our [contributing guidelines](https://github.com/intermine/bluegenes/blob/dev/CONTRIBUTING.md).


### Setting up a local development environment

[Building instructions (for both Dev and Production builds)](docs/building.md).

[Configuring a local build](docs/configuring.md)

[Development resources](docs/developing.md)


## Need further help?

- Regarding InterMine- and InterMine webservices-related problems, check out the [InterMine documentation](http://intermine.readthedocs.io/en/latest/about/contact-us/)
- Email our [dev list](http://intermine.readthedocs.io/en/latest/support/mailing-list/)
- [Chat with us](http://chat.intermine.org) during UK office hours


## License

Copyright (C) since 2016, BlueGenes contributors

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, version 2.1.

You should have received a copy of the GNU Lesser General Public License along with this program.
If not, see <http://www.gnu.org/licenses/>.
